<?php

namespace Drupal\Tests\image_catcher\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\image_catcher\Data;

/**
 * Tests images creation.
 *
 * @coversDefaultClass \Drupal\image_catcher\FileManager
 */
abstract class ImageCatcherTest extends KernelTestBase {

  /**
   * File Storage.
   *
   * @var [type]
   */
  protected $fileStorage;

  /**
   * Image Catcher service.
   *
   * @var \Drupal\image_catcher\ImageCatcher
   */
  protected $imageCatcher;

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'file',
    'image_catcher',
    'pathauto',
    'system',
    'token',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    prent::setUp();
    $this->imageCatcher = $this->container->get('image_catcher.manager');
    $this->fileStorage = $this->container->get('entity_type.manager')->getStorage('file');
  }

  /**
   * Test CreateFromBase64 method.
   *
   * @covers ::createFromBase64
   *
   * @dataprovider createFromBase64Provider
   */
  public function testCreateFromBase64(string $image_base64, string $dir_name, string $image_name) {
    clearstatcache();
    $fid = $this->imageCatcher->createFromBase64($image_base64, $dir_name, $image_name);
    $this->assertTrue(!empty($fid), 'Image is stored in the database.');

    $file = $this->fileStorage->load($fid);
    $this->assertTrue(file_exists($file->getFileUri()), 'Image file exists.');
  }

  /**
   * Data provider for ::testCreateFromBase64.
   *
   * @return array
   *   Data.
   */
  public function createFromBase64Provider() {
    return [
      [Data::BASE_64_IMG_TEST, "image_catcher", "drupal-8.png"],
    ];
  }

}
