<?php

namespace Drupal\Tests\image_catcher\Unit;

use Drupal\Core\Utility\Token;
use Drupal\image_catcher\ImageCatcher;
use Drupal\pathauto\AliasCleaner;
use Drupal\Tests\image_catcher\Data;
use Drupal\Tests\UnitTestCase;

/**
 * Covers ImageCatcher.
 */
class ImageCatcherTest implements UnitTestCase {

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->tokenManagerProphecy = $this->prophesize(Token::CLASS);
    $this->aliascleanerProphecy = $this->prophesize(AliasCleaner::CLASS);
    $this->rubricAccessChecker = new ImageCatcher($this->tokenManagerProphecy->reveal(), $this->aliascleanerProphecy->reveal());
  }

  /**
   * Test createFromBase64 method with no mime type.
   *
   * @covers ::createFromBase64
   *
   * @dataprovider createFromBase64NoMimeProvider
   */
  public function testCreateFromBase64NoMime(string $image_base64, string $dir_name, string $image_name) {
    $this->aliascleanerProphecy->cleanString($image_name)->willReturn($image_name);
    $this->assertFalse($this->rubricAccessChecker->createFromBase64($image_base64, $dir_name, $image_name));
  }

  /**
   * Test createFromBase64 method with wrong mime type.
   *
   * @covers ::createFromBase64
   *
   * @dataprovider createFromBase64WrongMimeProvider
   */
  public function testCreateFromBase64WrongMime(string $image_base64, string $dir_name, string $image_name) {
    $this->aliascleanerProphecy->cleanString($image_name)->willReturn($image_name);
    $this->assertFalse($this->rubricAccessChecker->createFromBase64($image_base64, $dir_name, $image_name));
  }

  /**
   * Provide data for ::testCreateFromBase64NoMime.
   */
  public function createFromBase64NoMimeProvider() {
    return [
      [Data::BASE_64_NO_MIME_TYPE, "image_catcher", "drupal-8.png"],
    ];
  }

  /**
   * Provide data for ::testCreateFromBase64WrongMime.
   */
  public function createFromBase64WrongMimeProvider() {
    return [
      [Data::BASE_64_WRONG_MIME_TYPE, "image_catcher", "drupal-8.png"],
    ];
  }

}
